KeyTable examples - KeyTable examples

# KeyTable example KeyTable examples

The examples shown in this section demonstrate the basic initialisation and features of KeyTable.

### Initialisation

- Basic initialisation
- Events
- Scrolling table
- Scroller integration
- Server-side processing
- State saving
- Keep focus (no blur)

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2017
DataTables is licensed under the MIT license.